
from setuptools import setup

setup(name="history-exploiter",
	version="1.2",
	description="Lets you selectively manipulate the browsing history in Firefox",
	url="https://github.com/ashish-pandey/HistoryExploiter.git",
	author="Ashish Pandey",
	author_email="apndey.15@gmail.com",
	license='MIT',
	packages=["history-exploiter"],
	scripts=["bin/history-exploiter"],
	zip_safe=False)
